FAQ — Scikit-HEP 0.0.1 documentation

# FAQ

## What is the exact project name?

The project is called Scikit-HEP. Notice the upper-case “S” and “HEP”. That is distinct from the core package, which is scikit-hep.

## How to pronounce the project name?

Like “sy-kit happ”(y), forgetting about the “y” in “happy”. Of course “sci” stands for science.

## How to get started contributing?

Please refer to the link contributing to Scikit-HEP for details on how to get involved.

## Is there support for PyPy?

It’s a nice idea. Support for PyPy could be envisaged in the near future but only once the scientific stack based on NumPy supports it.

## Is there support for GPUs?

Support for GPU-oriented code is not foreseen in the core package scikit-hep itself in the near- or even medium-term future. This would introduce non-trivial dependencies. This being said, there are already ideas to bring along affiliated packages specifically targetting data-intensive work, so code running on both CPUs and GPUs.